"use strict";
const kit_1 = require("@salesforce/kit");
const sfdx_trust_1 = require("@salesforce/sfdx-trust");
const cli_ux_1 = require("cli-ux");
const _ = require("lodash");
const timedHook_1 = require("../timedHook");
async function run(config, { plugin, tag }) {
    const cliUx = new cli_ux_1.CLI();
    cliUx.action.stop('Checking for digital signature.');
    const vConfig = new sfdx_trust_1.VerificationConfig();
    const npmName = sfdx_trust_1.NpmName.parse(plugin);
    npmName.tag = tag;
    const configContext = {
        cacheDir: _.get(config, 'configDir'),
        configDir: _.get(config, 'cacheDir'),
        dataDir: _.get(config, 'dataDir')
    };
    vConfig.verifier = new sfdx_trust_1.InstallationVerification()
        .setPluginNpmName(npmName)
        .setConfig(configContext);
    vConfig.log = cliUx.log.bind(cliUx);
    vConfig.prompt = cliUx.prompt.bind(cliUx);
    let namedError;
    try {
        await sfdx_trust_1.doInstallationCodeSigningVerification(configContext, { plugin, tag }, vConfig);
    }
    catch (e) {
        if (e instanceof kit_1.NamedError) {
            namedError = e;
        }
        throw e;
    }
    finally {
        if (namedError) {
            cliUx.action.start('Finished digital signature check. Skipping');
        }
        else {
            cliUx.action.start('Finished digital signature check. Installing');
        }
    }
}
module.exports = timedHook_1.default('plugins:preinstall:signing', run);
//# sourceMappingURL=verifyInstallSignature.js.map